powered by
Promote_types
torch_promote_types(type1, type2)
(torch.dtype)
torch.dtype
Returns the torch_dtype with the smallest size and scalar kind that is not smaller nor of lower kind than either type1 or type2. See type promotion documentation for more information on the type promotion logic.
torch_dtype
type1
type2
# NOT RUN { if (torch_is_installed()) { torch_promote_types(torch_int32(), torch_float32()) torch_promote_types(torch_uint8(), torch_long()) } # }
Run the code above in your browser using DataLab